**Autobahn**|Python
-------------------

*Open-source real-time framework for Web, Mobile & Internet of Things.*

----

**Autobahn**|Python is part of the `Autobahn <http://autobahn.ws>`__ project
and provides open-source implementations of

* The WebSocket Protocol
* The Web Application Messaging Protocol (WAMP)

for **Twisted** and **asyncio**, on **Python 2** and **Python 3** and
for writing **servers** and **clients**.

WebSocket allows **bidirectional real-time messaging** on the Web and WAMP
adds asynchronous **Remote Procedure Calls** and **Publish & Subscribe** on
top of WebSocket.

More information:

* `Documentation <http://autobahn.ws/python>`__
* `Source Code <https://github.com/tavendo/AutobahnPython>`__
* `WAMP <http://wamp.ws>`__
